<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}
/*
 * @package timeline builder
 * since 1.0.0
 * 
*/

add_image_size('swp_timeline_image_468×320', 468, 320, true);

function swp_timeline_get_thumbnail_alt($thumbnail_id)
{
  return get_post_meta($thumbnail_id, '_wp_attachment_image_alt', true);
}


if (!function_exists('swp_timeline_get_template')) :
  function swp_timeline_get_template($template_name = null)
  {
    $template_path = apply_filters('swp-timeline-elementor/template-path', 'elementor-templates/');
    $template = locate_template($template_path . $template_name);
    if (!$template) {
      $template = SWP_TIMELINE_ELEMENTOR  . '/templates/' . $template_name;
    }
    if (file_exists($template)) {
      return $template;
    } else {
      return false;
    }
  }
endif;


//select category
function swp_timeline_post_category()
{

  $terms = get_terms(array(
    'taxonomy'       => 'category',
    'hide_empty'     => false,
    'posts_per_page' => -1,
  ));

  $category_list = [];
  foreach ($terms as $post) {
    $category_list[$post->term_id] = [$post->name];
  }

  return $category_list;
}


//select tag
function swp_timeline_post_tag()
{

  $terms = get_terms(array(
    'taxonomy'       => 'post_tag',
    'hide_empty'     => false,
    'posts_per_page' => -1,
  ));

  $tag_list = [];
  foreach ($terms as $post) {
    $tag_list[$post->term_id] = [$post->name];
  }

  return $tag_list;
}

/*
* post tag
*/

function swp_timeline_post_date()
{
  $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
  if (get_the_time('U') !== get_the_modified_time('U')) {
    $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
  }

  $time_string = sprintf(
    $time_string,
    esc_attr(get_the_date(DATE_W3C)),
    esc_html(get_the_date()),
    esc_attr(get_the_modified_date(DATE_W3C)),
    esc_html(get_the_modified_date())
  );

  $posted_on = sprintf(
    /* translators: %s: post date. */
    esc_html_x('%s', 'post date', 'swp-timeline'), // phpcs:ignore WordPress.WP.I18n.NoEmptyStrings
    '<a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a>'
  );

  echo '<span class="date">' . $posted_on . '</span>'; // WPCS: XSS OK.
}



//select category
function swp_woo_timeline_post_category()
{

  $terms = get_terms(array(
    'taxonomy'       => 'product_cat',
    'hide_empty'     => false,
    'posts_per_page' => -1,
  ));

  $category_list = [];
  foreach ($terms as $post) {
    $category_list[$post->term_id] = [$post->name];
  }

  return $category_list;
}


//select tag
function swp_woo_timeline_post_tag()
{

  $terms = get_terms(array(
    'taxonomy'       => 'product_tag',
    'hide_empty'     => false,
    'posts_per_page' => -1,
  ));

  $tag_list = [];
  foreach ($terms as $post) {
    $tag_list[$post->term_id] = [$post->name];
  }

  return $tag_list;
}

/*
* post tag
*/

function swp_woo_timeline_post_date()
{
  $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
  if (get_the_time('U') !== get_the_modified_time('U')) {
    $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
  }

  $time_string = sprintf(
    $time_string,
    esc_attr(get_the_date(DATE_W3C)),
    esc_html(get_the_date())
  );

  $posted_on = sprintf(
    /* translators: %s: post date. */
    esc_html_x('%s', 'post date', 'swp-woo-timeline'), // phpcs:ignore WordPress.WP.I18n.NoEmptyStrings
    '<a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a>'
  );

  echo '<span class="date">' . $posted_on . '</span>'; // WPCS: XSS OK. Only the publish date will be displayed.

}

// add to cart button
if (!function_exists('swp_woo_timeline_add_to_cart_button')) {
  function swp_woo_timeline_add_to_cart_button()
  {
    global $product;
    $swp_woo_timeline_ajax_cart_class = (get_option('woocommerce_enable_ajax_add_to_cart') == 'yes' ? 'swp_woo_timeline_ajax' : '');
    if ($product->is_type('variable')) {

      echo sprintf(
        '<a href="%s" class="%s">%s</a>',
        esc_url($product->add_to_cart_url()),
        esc_attr(implode(' ', array_filter(array(
          'button', 'product_type_' . $product->get_type(),
          'swp-readmore-arrow swp-add-to-cart'
        )))),
        '<i class="fas fa-shopping-cart"></i>'
      );
    } else {
      echo sprintf(
        '<a href="%s" data-quantity="1" class="%s" %s>%s</a>',
        esc_url($product->add_to_cart_url()),
        esc_attr(implode(' ', array_filter(array(
          'button', 'product_type_' . $product->get_type(),
          $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
          $product->supports('ajax_add_to_cart') ? 'swp-readmore-arrow swp-add-to-cart ajax_add_to_cart' : 'swp-readmore-arrow swp-add-to-cart ',
          $swp_woo_timeline_ajax_cart_class
        )))),
        wc_implode_html_attributes(array(
          'data-product_id'  => $product->get_id(),
          'data-product_sku' => $product->get_sku(),
          'aria-label'       => $product->add_to_cart_description(),
          'rel'              => 'nofollow',
        )),
        '<i class="fas fa-shopping-cart"></i>'
      );
    }
  }
}


add_filter('woocommerce_add_to_cart_fragments', 'swp_woo_timeline_add_to_cart_message_ajax');
if (!function_exists('swp_woo_timeline_add_to_cart_message_ajax')) {
  function swp_woo_timeline_add_to_cart_message_ajax($fragments)
  {
    // Customize the message
    $message = '<div id="swp-timeline-custom-message" class="swp-timeline-custom-message"><i class="fas fa-check"></i>' . esc_html__('Product added successfully', 'swp-woo-timeline') . '</div>';
    $fragments['custom_message'] = $message;
    return $fragments;
  }
}

if (!function_exists('swp_woo_timeline_body_classes')) {
  function swp_woo_timeline_body_classes($classes)
  {
    $classes[] = 'product';

    return $classes;
  }
  add_filter('body_class', 'swp_woo_timeline_body_classes');
}
